Acknowledging or Citing SunPy
=============================

If you use SunPy in your scientific work, we would appreciate citing it in your publications.
The continued growth and development of SunPy is dependent on the community being aware of SunPy.

Citing SunPy in Publications
----------------------------

Please add the following line within your methods, conclusion or acknowledgements sections:

   *This research used version X.Y.Z (software citation) of the SunPy open source
   software package (project citation).*

The project citation should be to the `SunPy paper`_, and the software citation should be the specific `Zenodo DOI`_ for the version used in your work.

.. code:: bibtex

    @ARTICLE{sunpy_community2020,
      doi = {10.3847/1538-4357/ab4f7a},
      url = {https://iopscience.iop.org/article/10.3847/1538-4357/ab4f7a},
      author = {{The SunPy Community} and Barnes, Will T. and Bobra, Monica G. and Christe, Steven D. and Freij, Nabil and Hayes, Laura A. and Ireland, Jack and Mumford, Stuart and Perez-Suarez, David and Ryan, Daniel F. and Shih, Albert Y. and Chanda, Prateek and Glogowski, Kolja and Hewett, Russell and Hughitt, V. Keith and Hill, Andrew and Hiware, Kaustubh and Inglis, Andrew and Kirk, Michael S. F. and Konge, Sudarshan and Mason, James Paul and Maloney, Shane Anthony and Murray, Sophie A. and Panda, Asish and Park, Jongyeob and Pereira, Tiago M. D. and Reardon, Kevin and Savage, Sabrina and Sipőcz, Brigitta M. and Stansby, David and Jain, Yash and Taylor, Garrison and Yadav, Tannmay and Rajul and Dang, Trung Kien},
      title = {The SunPy Project: Open Source Development and Status of the Version 1.0 Core Package},
      journal = {The Astrophysical Journal},
      volume = {890},
      issue = {1},
      pages = {68-},
      publisher = {American Astronomical Society},
      year = {2020}
    }

You can also get this information with ``sunpy.__citation__``.

Other SunPy publications
########################

The SunPy v1.0.8 code was reviewed by `The Journal of Open Source Software (JOSS) <https://joss.theoj.org/papers/10.21105/joss.01832>`__.

.. code:: bibtex

    @ARTICLE{Mumford2020,
      doi = {10.21105/joss.01832},
      url = {https://doi.org/10.21105/joss.01832},
      year = {2020},
      publisher = {The Open Journal},
      volume = {5},
      number = {46},
      pages = {1832},
      author = {Stuart Mumford and Nabil Freij and Steven Christe and Jack Ireland and Florian Mayer and V. Hughitt and Albert Shih and Daniel Ryan and Simon Liedtke and David Pérez-Suárez and Pritish Chakraborty and Vishnunarayan K and Andrew Inglis and Punyaslok Pattnaik and Brigitta Sipőcz and Rishabh Sharma and Andrew Leonard and David Stansby and Russell Hewett and Alex Hamilton and Laura Hayes and Asish Panda and Matt Earnshaw and Nitin Choudhary and Ankit Kumar and Prateek Chanda and Md Haque and Michael Kirk and Michael Mueller and Sudarshan Konge and Rajul Srivastava and Yash Jain and Samuel Bennett and Ankit Baruah and Will Barnes and Michael Charlton and Shane Maloney and Nicky Chorley and Himanshu  and Sanskar Modi and James Mason and Naman9639  and Jose Rozo and Larry Manley and Agneet Chatterjee and John Evans and Michael Malocha and Monica Bobra and Sourav Ghosh and Airmansmith97  and Dominik Stańczak and Ruben De Visscher and Shresth Verma and Ankit Agrawal and Dumindu Buddhika and Swapnil Sharma and Jongyeob Park and Matt Bates and Dhruv Goel and Garrison Taylor and Goran Cetusic and Jacob  and Mateo Inchaurrandieta and Sally Dacie and Sanjeev Dubey and Deepankar Sharma and Erik Bray and Jai Rideout and Serge Zahniy and Tomas Meszaros and Abhigyan Bose and André Chicrala and Ankit  and Chloé Guennou and Daniel D'Avella and Daniel Williams and Jordan Ballew and Nick Murphy and Priyank Lodha and Thomas Robitaille and Yash Krishan and Andrew Hill and Arthur Eigenbrot and Benjamin Mampaey and Bernhard Wiedemann and Carlos Molina and Duygu Keşkek and Ishtyaq Habib and Joseph Letts and Juanjo Bazán and Quinn Arbolante and Reid Gomillion and Yash Kothari and Yash Sharma and Abigail Stevens and Adrian Price-Whelan and Ambar Mehrotra and Arseniy Kustov and Brandon Stone and Trung Dang and Emmanuel Arias and Fionnlagh Dover and Freek Verstringe and Gulshan Kumar and Harsh Mathur and Igor Babuschkin and Jaylen Wimbish and Juan Buitrago-Casas and Kalpesh Krishna and Kaustubh Hiware and Manas Mangaonkar and Matthew Mendero and Mickaël Schoentgen and Norbert Gyenge and Ole Streicher and Rajasekhar Mekala and Rishabh Mishra and Shashank Srikanth and Sarthak Jain and Tannmay Yadav and Tessa Wilkinson and Tiago Pereira and Yudhik Agrawal and Jamescalixto  and Yasintoda  and Sophie Murray},
      title = {SunPy: A Python package for Solar Physics},
      journal = {Journal of Open Source Software}
    }

A paper about version v0.5 of SunPy was published in `Computational Science & Discovery <https://iopscience.iop.org/article/10.1088/1749-4699/8/1/014009>`__.

Acknowledging SunPy in Posters and Talks
----------------------------------------

Please include the `Sunpy logo`_ on the title, conclusion slide, or about page.
For websites please link the image to `sunpy.org`_.
Other versions of the logo are available in the `sunpy-logo repository`_.

.. _SunPy paper: https://doi.org/10.3847/1538-4357/ab4f7a
.. _Sunpy logo: https://github.com/sunpy/sunpy-logo/blob/master/sunpy_logo.svg
.. _sunpy.org: https://sunpy.org/
.. _sunpy-logo repository: https://github.com/sunpy/sunpy-logo/
.. _Zenodo DOI: https://doi.org/10.5281/zenodo.591887
